# Python util funcs

[![codecov](https://codecov.io/gh/hyukkyukang/python_utils/branch/main/graph/badge.svg?token=XM8ELS08EG)](https://codecov.io/gh/hyukkyukang/python_utils)

This is a collection of python functions that I use in my projects.

To install [the package](https://pypi.org/project/hkkang-utils/):

```bash
pip install hkkang_utils
```

Documentation is available [here](https://hyukkyukang.github.io/python_utils/).
